@@ -19,15 +19,12 @@
 
 #include "detailedQmlView.h"
 
-
-
-#include <QVBoxLayout>
-#include <QDeclarativeView>
-
 #include <QDebug>
-#include <prefs.h>
+#include <QDeclarativeView>
 #include <QStandardPaths>
+#include <QVBoxLayout>
 
+#include <prefs.h>
 #include "kalziumdataobject.h"
 #include "kalziumutils.h"
 
@@ -46,7 +43,7 @@ DetailedQmlView::DetailedQmlView(QWidget *parent) : QWidget(parent)
     view->setSource(QUrl::fromLocalFile(qmlPath + "detailview.qml"));
 
     layout->addWidget(view);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     setLayout(layout);
 
 //     resize(200, 200);
